@@ -14,6 +14,14 @@ beautify <- function(escapeBraces_b_1 = FALSE) {
                        'code'))
 
   l <- sapply(candidates, generateFunction)
-  l$codelink <- function(entries) l$code(l$link(entries))
+  l$codeLink <- function(entries_s) l$code(l$link(entries_s))
+  l$enhanceCodeLink <- function(entries_s) l$emph(l$bold(l$code(l$link(entries_s))))
+
+  l$italicCode <-  function(entries_s) l$emph(l$code(entries_s))
+  l$boldCode <-  function(entries_s) l$bold(l$code(entries_s))
+
+  l$R <- function() { generateMarkup(keyword_s_1 = 'R')}
+  l$ldots <- function() { generateMarkup(keyword_s_1 = 'ldots')}
+  l$dots <- function() { generateMarkup(keyword_s_1 = 'dots')}
   l
 }
