@@ -14,7 +14,7 @@ test_that("outOfPackage - coverage", {
   expect_equal(capitalize(45L), 45L)
   expect_equal(capitalize(''), '')
   expect_equal(capitalize('f'), 'F')
-  expect_true(is.character(lubridate::date()))
+  expect_true(is.character(as.character(Sys.time())))
 
   expect_equal(normalizeFilename('a-<-'), "a--_ee97e9bb28882d92fa97001097fd97ba")
 })
